@@ -64,6 +64,7 @@ class RDBService:
             #logging.debug("New a record into {}: {}".format(table, data))
         except Exception as e:
             traceback.print_exc()
+            logging.warnning('while excute insert new data({}) in {}'.format(table,data))
             self.close()
 
 
@@ -71,7 +72,7 @@ class RDBService:
     """
     query = "where a=b or (c like 'd')" sql子句
     """
-    def find_one(self, table, query,fields=None):
+    def find_one(self, table, query,sort=None,fields=None):
         raise (NameError, "Unsupported")
 
     # 根据${query}查找多条记录
@@ -104,6 +105,7 @@ class RDBService:
 
         except Exception as e:
             traceback.print_exc()
+            logging.warnning('while excute updating({}) sql with query({}) in {}'.format(update,table,query))
             self.close()
 
     def delete(self,table,query):
@@ -118,6 +120,7 @@ class RDBService:
             #logging.debug('数据删除成功！')
         except Exception as e:
             traceback.print_exc()
+            logging.warnning('while excute deleting sql with query({}) in {}'.format(table,query))
             self.close()
 
     def count(self,table,query):
@@ -133,6 +136,7 @@ class RDBService:
 
         except Exception as e:
             traceback.print_exc()
+            logging.warnning('while excute counting sql with query({}) in {}'.format(table,query))
             self.close()
 
 
@@ -172,7 +176,7 @@ class MssqlService(RDBService):
     """
     query = "where a=b or (c like 'd')" sql子句
     """
-    def find_one(self, table, query,fields=None):
+    def find_one(self, table, query,sort=None,fields=None):
         try:
             self.__connect()
             s='*'
@@ -180,7 +184,7 @@ class MssqlService(RDBService):
             if fields is not None:
                 s=','.join(fields)
 
-            sql = 'select top 1 {} from {} {}'.format(s,table, query)
+            sql = 'select top 1 {} from {} {} {}'.format(s,table, query,sort)
             cusor = self.conn.cursor()
             if not cusor:
                 raise (NameError, "连接数据库失败")
@@ -191,6 +195,7 @@ class MssqlService(RDBService):
                 return res[0] if len(res) > 0 else None
         except Exception as e:
             self.close()
+            logging.warnning('while excute find_one sql with query({}) in {}'.format(table,query))
             raise e
 
     # 根据${query}查找多条记录
@@ -218,6 +223,7 @@ class MssqlService(RDBService):
                 return result
         except Exception as e:
             self.close()
+            logging.warnning('while excute find sql with query({}) in {}'.format(table,query))
             raise e
 
 
@@ -235,7 +241,7 @@ class MysqlService(RDBService):
     """
     query = "where a=b or (c like 'd')" sql子句
     """
-    def find_one(self, table, query,fields=None):
+    def find_one(self, table, query,sort=None,fields=None):
         try:
             self.__connect()
             s='*'
@@ -243,7 +249,7 @@ class MysqlService(RDBService):
             if fields is not None:
                 s=','.join(fields)
 
-            sql = 'select {} from {} {} limit 1'.format(s,table, query)
+            sql = 'select {} from {} {} {} limit 1'.format(s,table, query,sort)
             cusor = self.conn.cursor()
             res = cusor.execute(sql)
             res = cusor.fetchall()
@@ -251,8 +257,33 @@ class MysqlService(RDBService):
             return res[0] if len(res) > 0 else None
         except Exception as e:
             self.__close()
+            logging.warnning('while excute find_one sql with query({}) in {}'.format(table,query))
             raise e
 
+#根据${query}查找多条记录
+    """
+    query = "where a=b or (c like 'd')" sql子句
+    sort : 'order by ${fields} ${asc|desc}
+    page_site: 分页大小 
+    """
+    def find(self,table,query,sort,fields):
+        try:
+            self.__connect()
+            if fields is None:
+                sql = 'select  * from {} {} {}'.format(table, query, sort)
+            else:
+                sql = 'select {} from {} {} {}'.format(','.join(fields), table, query, sort)
+            cusor = self.conn.cursor()
+            result = cusor.execute(sql)
+            result = cusor.fetchall()
+            cusor.close()
+
+            # return {'total': count,'result': result}
+            return result
+        except Exception as e:
+            self.__close()
+            logging.warnning('while excute find sql with query({}) in {}'.format(table,query))
+            raise e
 
 class PostgresqlService(RDBService):
     def __init__(self,settings):
@@ -286,6 +317,7 @@ class PostgresqlService(RDBService):
             return result
         except Exception as e:
             self.__close()
+            logging.warnning('while excute find sql with query({}) in {}'.format(table,query))
             raise e
 
 
@@ -295,7 +327,7 @@ class PostgresqlService(RDBService):
     """
     query = "where a=b or (c like 'd')" sql子句
     """
-    def find_one(self, table, query,fields=None):
+    def find_one(self, table, query,sort=None,fields=None):
         try:
             self.__connect()
             s='*'
@@ -303,7 +335,7 @@ class PostgresqlService(RDBService):
             if fields is not None:
                 s=','.join(fields)
 
-            sql = 'select {} from {} {} limit 1'.format(s,table, query)
+            sql = 'select {} from {} {} {} limit 1'.format(s,table, query,sort)
             cusor = self.conn.cursor()
             res = cusor.execute(sql)
             res = cusor.fetchall()
@@ -311,30 +343,7 @@ class PostgresqlService(RDBService):
             return res[0] if len(res) > 0 else None
         except Exception as e:
             self.__close()
-            raise e
-
-    #根据${query}查找多条记录
-    """
-    query = "where a=b or (c like 'd')" sql子句
-    sort : 'order by ${fields} ${asc|desc}
-    page_site: 分页大小 
-    """
-    def find(self,table,query,sort,fields):
-        try:
-            self.__connect()
-            if fields is None:
-                sql = 'select  * from {} {} {}'.format(table, query, sort)
-            else:
-                sql = 'select {} from {} {} {}'.format(','.join(fields), table, query, sort)
-            cusor = self.conn.cursor()
-            result = cusor.execute(sql)
-            result = cusor.fetchall()
-            cusor.close()
-
-            # return {'total': count,'result': result}
-            return result
-        except Exception as e:
-            self.__close()
+            logging.warnning('while excute find_one sql with query({}) in {}'.format(table,query))
             raise e
 
 
@@ -348,3 +357,5 @@ class PostgresqlService(RDBService):
 
 
 
+
+
